/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'sv', {
	border: 'Visa ramkant',
	noUrl: 'Skriv in URL för iFrame',
	scrolling: 'Aktivera rullningslister',
	title: 'iFrame-egenskaper',
	toolbar: 'iFrame',
	tabindex: 'Ta bort från tabindex'
} );
